summaryrefslogtreecommitdiff
path: root/src/core/string.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/string.h')
-rw-r--r--src/core/string.h18
1 files changed, 7 insertions, 11 deletions
diff --git a/src/core/string.h b/src/core/string.h
index d5a943a..3d5844a 100644
--- a/src/core/string.h
+++ b/src/core/string.h
@@ -1,3 +1,4 @@
+
/*
* This file is part of libdom.
* Licensed under the MIT License,
@@ -10,14 +11,9 @@
#include <dom/core/string.h>
-/* Create a DOM string from a lwc_string
- * This function call mainly used for create a string from lwc_string */
-dom_exception _dom_string_create_from_lwcstring(dom_alloc alloc, void *pw,
- struct lwc_string_s *str, dom_string **ret);
-
-/* Make the dom_string be interned */
-dom_exception _dom_string_intern(dom_string *str,
- struct lwc_string_s **lwcstr);
+/* Create a DOM string from a lwc_string */
+dom_exception _dom_string_create_from_lwcstring(struct lwc_string_s *str,
+ dom_string **ret);
/* Map the lwc_error to dom_exception */
dom_exception _dom_exception_from_lwc_error(lwc_error err);
@@ -27,10 +23,10 @@ dom_exception _dom_exception_from_lwc_error(lwc_error err);
* @note: This function is just provided for the convenience of accessing the
* raw C string character, no change on the result string is allowed.
*/
-char *_dom_string_data(dom_string *str);
+const char *_dom_string_data(dom_string *str);
-/* Get the string length of this dom_string */
-size_t _dom_string_length(dom_string *str);
+/* Get the byte length of this dom_string */
+size_t _dom_string_byte_length(dom_string *str);
#endif